========
Temporal
========

The following methods are available under the `expr.dt` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.dt.base_utc_offset
    Expr.dt.cast_time_unit
    Expr.dt.replace_time_zone
    Expr.dt.combine
    Expr.dt.date
    Expr.dt.datetime
    Expr.dt.day
    Expr.dt.days
    Expr.dt.dst_offset
    Expr.dt.epoch
    Expr.dt.hour
    Expr.dt.hours
    Expr.dt.is_leap_year
    Expr.dt.iso_year
    Expr.dt.microsecond
    Expr.dt.microseconds
    Expr.dt.millisecond
    Expr.dt.milliseconds
    Expr.dt.minute
    Expr.dt.minutes
    Expr.dt.month
    Expr.dt.month_start
    Expr.dt.month_end
    Expr.dt.nanosecond
    Expr.dt.nanoseconds
    Expr.dt.offset_by
    Expr.dt.ordinal_day
    Expr.dt.quarter
    Expr.dt.round
    Expr.dt.second
    Expr.dt.seconds
    Expr.dt.strftime
    Expr.dt.time
    Expr.dt.timestamp
    Expr.dt.to_string
    Expr.dt.total_days
    Expr.dt.total_hours
    Expr.dt.total_microseconds
    Expr.dt.total_milliseconds
    Expr.dt.total_minutes
    Expr.dt.total_nanoseconds
    Expr.dt.total_seconds
    Expr.dt.truncate
    Expr.dt.week
    Expr.dt.weekday
    Expr.dt.with_time_unit
    Expr.dt.convert_time_zone
    Expr.dt.year
